@@ -1,4 +1,6 @@
-package MyIterator;
+package # Hidden from pause
+  MyIterator;
+
 use strict;
 use warnings;
 use IO::File;
