@@ -8,7 +8,6 @@ use Data::Range::Compare::Stream::Iterator::File;
 use Data::Range::Compare::Stream;
 use Data::Range::Compare::Stream::Iterator::Consolidate::OverlapAsColumn;
 use Data::Range::Compare::Stream::Iterator::Compare::Asc;
-use Data::Range::Compare::Stream::Iterator::Compare::ColumnRelations;
 
 
 my $break="  +---------------------+----------------------------+\n";
@@ -24,7 +23,6 @@ foreach my $file (qw(source_a.src source_b.src source_c.src source_d.src)) {
     my $iterator=Data::Range::Compare::Stream::Iterator::File->new(filename=>$file);
     die unless $iterator->has_next;
     my $cmp=new  Data::Range::Compare::Stream::Iterator::Compare::Asc();
-    my $relations=new Data::Range::Compare::Stream::Iterator::Compare::ColumnRelations($cmp);
     my $con=new Data::Range::Compare::Stream::Iterator::Consolidate::OverlapAsColumn($iterator,$cmp);
     $cmp->add_consolidator($con);
 
@@ -35,8 +33,8 @@ foreach my $file (qw(source_a.src source_b.src source_c.src source_d.src)) {
 
       next if $result->is_empty;
 
-      my $columns=$relations->get_root_results($result);
-      push @row, join ', ',map { $_->get_common } @{$columns->{0}};
+      my $columns=$result->get_root_results;
+      push @row, join ', ',map { $_->get_common } @{$columns->[0]};
 
       printf $format,@row;
 
