@@ -17,6 +17,12 @@ sub new {
 sub get_next {
   my ($self)=@_;
 
+  if(defined($self->{filter})) {
+    my $result=$self->{next_result};
+    delete $self->{next_result};
+    return $result;
+  }
+
   if($self->{ignore_full}) {
     my $result=$self->{next_result};
     delete $self->{next_result};
@@ -43,14 +49,46 @@ sub prepare  {
   return if $self->prepared;
 
   $self->SUPER::prepare;
+  if(defined($self->{filter})) {
+    my $filter=$self->{filter};
 
 
+    while($self->SUPER::has_next) {
+      my $result=$self->SUPER::get_next;
+      if($filter->($result)) {
+        $self->{next_result}=$result;
+	return 1;
+      }
+    }
+    delete $self->{next_result};
+    return 0;
+
+  }
+
 }
 
 sub has_next {
   my ($self)=@_;
 
-  if($self->{ignore_full}) {
+  $self->prepare;
+  
+  if(defined($self->{filter})) {
+    my $filter=$self->{filter};
+
+    return 1 if defined($self->{next_result});
+
+
+    while($self->SUPER::has_next) {
+      my $result=$self->SUPER::get_next;
+      if($filter->($result)) {
+        $self->{next_result}=$result;
+	return 1;
+      }
+    }
+    delete $self->{next_result};
+    return 0;
+
+  } elsif($self->{ignore_full}) {
     return 1 if defined($self->{next_result});
 
     return 0 unless $self->SUPER::has_next;
